nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

FreqMeCtrl

Struct FreqMeCtrl 

#[repr(transparent)]
pub struct FreqMeCtrl(pub u32);
Frequency Measure function control register

Tuple Fields

0: u32

Implementations

Source

impl FreqMeCtrl

pub const fn capval_scale(&self) -> u32

Frequency measure result /Frequency measur scale

pub const fn set_capval_scale(&mut self, val: u32)

Frequency measure result /Frequency measur scale

pub const fn prog(&self) -> bool

Set this bit to one to initiate a frequency measurement cycle. Hardware clears this bit when the measurement cycle has completed and there is valid capture data in the CAPVAL field (bits 30:0).

pub const fn set_prog(&mut self, val: bool)

Set this bit to one to initiate a frequency measurement cycle. Hardware clears this bit when the measurement cycle has completed and there is valid capture data in the CAPVAL field (bits 30:0).