nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ringo0Ctrl

Struct Ringo0Ctrl 

#[repr(transparent)]
pub struct Ringo0Ctrl(pub u32);
First Ring Oscillator module control register.

Tuple Fields

0: u32

Implementations

Source

impl Ringo0Ctrl

pub const fn sl(&self) -> Sl

Select short or long ringo (for all ringos types).

pub const fn set_sl(&mut self, val: Sl)

Select short or long ringo (for all ringos types).

pub const fn fs(&self) -> Ringo0CtrlFs

Ringo frequency output divider.

pub const fn set_fs(&mut self, val: Ringo0CtrlFs)

Ringo frequency output divider.

pub const fn swn_swp(&self) -> SwnSwp

PN-Ringos (P-Transistor and N-Transistor processing) control.

pub const fn set_swn_swp(&mut self, val: SwnSwp)

PN-Ringos (P-Transistor and N-Transistor processing) control.

pub const fn pd(&self) -> Ringo0CtrlPd

Ringo module Power control.

pub const fn set_pd(&mut self, val: Ringo0CtrlPd)

Ringo module Power control.

pub const fn e_nd0(&self) -> bool

First NAND2-based ringo control.

pub const fn set_e_nd0(&mut self, val: bool)

First NAND2-based ringo control.

pub const fn e_nd1(&self) -> bool

Second NAND2-based ringo control.

pub const fn set_e_nd1(&mut self, val: bool)

Second NAND2-based ringo control.

pub const fn e_nr0(&self) -> bool

First NOR2-based ringo control.

pub const fn set_e_nr0(&mut self, val: bool)

First NOR2-based ringo control.

pub const fn e_nr1(&self) -> bool

Second NOR2-based ringo control.

pub const fn set_e_nr1(&mut self, val: bool)

Second NOR2-based ringo control.

pub const fn e_iv0(&self) -> bool

First Inverter-based ringo control.

pub const fn set_e_iv0(&mut self, val: bool)

First Inverter-based ringo control.

pub const fn e_iv1(&self) -> bool

Second Inverter-based ringo control.

pub const fn set_e_iv1(&mut self, val: bool)

Second Inverter-based ringo control.

pub const fn e_pn0(&self) -> bool

First PN (P-Transistor and N-Transistor processing) monitor control.

pub const fn set_e_pn0(&mut self, val: bool)

First PN (P-Transistor and N-Transistor processing) monitor control.

pub const fn e_pn1(&self) -> bool

Second PN (P-Transistor and N-Transistor processing) monitor control.

pub const fn set_e_pn1(&mut self, val: bool)

Second PN (P-Transistor and N-Transistor processing) monitor control.

pub const fn divisor(&self) -> u8

Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)

pub const fn set_divisor(&mut self, val: u8)

Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)

pub const fn div_update_req(&self) -> bool

Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.

pub const fn set_div_update_req(&mut self, val: bool)

Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.