nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Ringo1Ctrl

Struct Ringo1Ctrl 

#[repr(transparent)]
pub struct Ringo1Ctrl(pub u32);
Second Ring Oscillator module control register.

Tuple Fields

0: u32

Implementations

Source

impl Ringo1Ctrl

pub const fn s(&self) -> Ringo1CtrlS

Select short or long ringo (for all ringos types).

pub const fn set_s(&mut self, val: Ringo1CtrlS)

Select short or long ringo (for all ringos types).

pub const fn fs(&self) -> Ringo1CtrlFs

Ringo frequency output divider.

pub const fn set_fs(&mut self, val: Ringo1CtrlFs)

Ringo frequency output divider.

pub const fn pd(&self) -> Ringo1CtrlPd

Ringo module Power control.

pub const fn set_pd(&mut self, val: Ringo1CtrlPd)

Ringo module Power control.

pub const fn e_r24(&self) -> bool

.

pub const fn set_e_r24(&mut self, val: bool)

.

pub const fn e_r35(&self) -> bool

.

pub const fn set_e_r35(&mut self, val: bool)

.

pub const fn e_m2(&self) -> bool

Metal 2 (M2) monitor control.

pub const fn set_e_m2(&mut self, val: bool)

Metal 2 (M2) monitor control.

pub const fn e_m3(&self) -> bool

Metal 3 (M3) monitor control.

pub const fn set_e_m3(&mut self, val: bool)

Metal 3 (M3) monitor control.

pub const fn e_m4(&self) -> bool

Metal 4 (M4) monitor control.

pub const fn set_e_m4(&mut self, val: bool)

Metal 4 (M4) monitor control.

pub const fn e_m5(&self) -> bool

Metal 5 (M5) monitor control.

pub const fn set_e_m5(&mut self, val: bool)

Metal 5 (M5) monitor control.

pub const fn divisor(&self) -> u8

Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)

pub const fn set_divisor(&mut self, val: u8)

Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)

pub const fn div_update_req(&self) -> bool

Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.

pub const fn set_div_update_req(&mut self, val: bool)

Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.