#[repr(transparent)]pub struct Ringo2Ctrl(pub u32);Expand description
Third Ring Oscillator module control register.
Tuple Fields
0: u32Implementations
Sourceimpl Ringo2Ctrl
impl Ringo2Ctrl
Sourcepub const fn s(&self) -> Ringo2CtrlS
pub const fn s(&self) -> Ringo2CtrlS
Select short or long ringo (for all ringos types).
Sourcepub const fn set_s(&mut self, val: Ringo2CtrlS)
pub const fn set_s(&mut self, val: Ringo2CtrlS)
Select short or long ringo (for all ringos types).
Sourcepub const fn fs(&self) -> Ringo2CtrlFs
pub const fn fs(&self) -> Ringo2CtrlFs
Ringo frequency output divider.
Sourcepub const fn set_fs(&mut self, val: Ringo2CtrlFs)
pub const fn set_fs(&mut self, val: Ringo2CtrlFs)
Ringo frequency output divider.
Sourcepub const fn pd(&self) -> Ringo2CtrlPd
pub const fn pd(&self) -> Ringo2CtrlPd
Ringo module Power control.
Sourcepub const fn set_pd(&mut self, val: Ringo2CtrlPd)
pub const fn set_pd(&mut self, val: Ringo2CtrlPd)
Ringo module Power control.
Sourcepub const fn divisor(&self) -> u8
pub const fn divisor(&self) -> u8
Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)
Sourcepub const fn set_divisor(&mut self, val: u8)
pub const fn set_divisor(&mut self, val: u8)
Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)
Sourcepub const fn div_update_req(&self) -> bool
pub const fn div_update_req(&self) -> bool
Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.
Sourcepub const fn set_div_update_req(&mut self, val: bool)
pub const fn set_div_update_req(&mut self, val: bool)
Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.