nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Xo32mCtrl

Struct Xo32mCtrl 

#[repr(transparent)]
pub struct Xo32mCtrl(pub u32);
High speed Crystal Oscillator Control register

Tuple Fields

0: u32

Implementations

Source

impl Xo32mCtrl

pub const fn slave(&self) -> bool

Xo in slave mode.

pub const fn set_slave(&mut self, val: bool)

Xo in slave mode.

pub const fn osc_cap_in(&self) -> u8

Tune capa banks of High speed Crystal Oscillator input pin

pub const fn set_osc_cap_in(&mut self, val: u8)

Tune capa banks of High speed Crystal Oscillator input pin

pub const fn osc_cap_out(&self) -> u8

Tune capa banks of High speed Crystal Oscillator output pin

pub const fn set_osc_cap_out(&mut self, val: u8)

Tune capa banks of High speed Crystal Oscillator output pin

pub const fn acbuf_pass_enable(&self) -> bool

Bypass enable of XO AC buffer enable in pll and top level.

pub const fn set_acbuf_pass_enable(&mut self, val: bool)

Bypass enable of XO AC buffer enable in pll and top level.

pub const fn enable_pll_usb_out(&self) -> bool

Enable High speed Crystal oscillator output to USB HS PLL.

pub const fn set_enable_pll_usb_out(&mut self, val: bool)

Enable High speed Crystal oscillator output to USB HS PLL.

pub const fn enable_system_clk_out(&self) -> bool

Enable High speed Crystal oscillator output to CPU system.

pub const fn set_enable_system_clk_out(&mut self, val: bool)

Enable High speed Crystal oscillator output to CPU system.