#[repr(transparent)]pub struct Fro192mCtrl(pub u32);Expand description
192MHz Free Running OScillator (FRO) Control register
Tuple Fields
0: u32Implementations
Sourceimpl Fro192mCtrl
impl Fro192mCtrl
Sourcepub const fn ena_12mhzclk(&self) -> bool
pub const fn ena_12mhzclk(&self) -> bool
12 MHz clock control.
Sourcepub const fn set_ena_12mhzclk(&mut self, val: bool)
pub const fn set_ena_12mhzclk(&mut self, val: bool)
12 MHz clock control.
Sourcepub const fn ena_48mhzclk(&self) -> bool
pub const fn ena_48mhzclk(&self) -> bool
48 MHz clock control.
Sourcepub const fn set_ena_48mhzclk(&mut self, val: bool)
pub const fn set_ena_48mhzclk(&mut self, val: bool)
48 MHz clock control.
Sourcepub const fn set_dac_trim(&mut self, val: u8)
pub const fn set_dac_trim(&mut self, val: u8)
Frequency trim.
Sourcepub const fn usbclkadj(&self) -> bool
pub const fn usbclkadj(&self) -> bool
If this bit is set and the USB peripheral is enabled into full speed device mode, the USB block will provide FRO clock adjustments to lock it to the host clock using the SOF packets.
Sourcepub const fn set_usbclkadj(&mut self, val: bool)
pub const fn set_usbclkadj(&mut self, val: bool)
If this bit is set and the USB peripheral is enabled into full speed device mode, the USB block will provide FRO clock adjustments to lock it to the host clock using the SOF packets.
Sourcepub const fn usbmodchg(&self) -> bool
pub const fn usbmodchg(&self) -> bool
If it reads as 1 when reading the DAC_TRIM field and USBCLKADJ=1, it should be re-read until it is 0.
Sourcepub const fn set_usbmodchg(&mut self, val: bool)
pub const fn set_usbmodchg(&mut self, val: bool)
If it reads as 1 when reading the DAC_TRIM field and USBCLKADJ=1, it should be re-read until it is 0.
Sourcepub const fn ena_96mhzclk(&self) -> bool
pub const fn ena_96mhzclk(&self) -> bool
96 MHz clock control.
Sourcepub const fn set_ena_96mhzclk(&mut self, val: bool)
pub const fn set_ena_96mhzclk(&mut self, val: bool)
96 MHz clock control.
Sourcepub const fn wrtrim(&self) -> bool
pub const fn wrtrim(&self) -> bool
This must be written to 1 to modify the BIAS_TRIM and TEMP_TRIM fields.
Sourcepub const fn set_wrtrim(&mut self, val: bool)
pub const fn set_wrtrim(&mut self, val: bool)
This must be written to 1 to modify the BIAS_TRIM and TEMP_TRIM fields.