#[repr(transparent)]pub struct Fro192mStatus(pub u32);Expand description
192MHz Free Running OScillator (FRO) Status register
Tuple Fields
0: u32Implementations
Sourceimpl Fro192mStatus
impl Fro192mStatus
Sourcepub const fn clk_valid(&self) -> bool
pub const fn clk_valid(&self) -> bool
Output clock valid signal. Indicates that CCO clock has settled.
Sourcepub const fn set_clk_valid(&mut self, val: bool)
pub const fn set_clk_valid(&mut self, val: bool)
Output clock valid signal. Indicates that CCO clock has settled.
Sourcepub const fn atb_vctrl(&self) -> bool
pub const fn atb_vctrl(&self) -> bool
CCO threshold voltage detector output (signal vcco_ok). Once the CCO voltage crosses the threshold voltage of a SLVT transistor, this output signal will go high. It is also possible to observe the clk_valid signal.
Sourcepub const fn set_atb_vctrl(&mut self, val: bool)
pub const fn set_atb_vctrl(&mut self, val: bool)
CCO threshold voltage detector output (signal vcco_ok). Once the CCO voltage crosses the threshold voltage of a SLVT transistor, this output signal will go high. It is also possible to observe the clk_valid signal.