#[repr(transparent)]pub struct Ringo0Ctrl(pub u32);Expand description
First Ring Oscillator module control register.
Tuple Fields
0: u32Implementations
Sourceimpl Ringo0Ctrl
impl Ringo0Ctrl
Sourcepub const fn fs(&self) -> Ringo0CtrlFs
pub const fn fs(&self) -> Ringo0CtrlFs
Ringo frequency output divider.
Sourcepub const fn set_fs(&mut self, val: Ringo0CtrlFs)
pub const fn set_fs(&mut self, val: Ringo0CtrlFs)
Ringo frequency output divider.
Sourcepub const fn swn_swp(&self) -> SwnSwp
pub const fn swn_swp(&self) -> SwnSwp
PN-Ringos (P-Transistor and N-Transistor processing) control.
Sourcepub const fn set_swn_swp(&mut self, val: SwnSwp)
pub const fn set_swn_swp(&mut self, val: SwnSwp)
PN-Ringos (P-Transistor and N-Transistor processing) control.
Sourcepub const fn pd(&self) -> Ringo0CtrlPd
pub const fn pd(&self) -> Ringo0CtrlPd
Ringo module Power control.
Sourcepub const fn set_pd(&mut self, val: Ringo0CtrlPd)
pub const fn set_pd(&mut self, val: Ringo0CtrlPd)
Ringo module Power control.
Sourcepub const fn e_pn0(&self) -> bool
pub const fn e_pn0(&self) -> bool
First PN (P-Transistor and N-Transistor processing) monitor control.
Sourcepub const fn set_e_pn0(&mut self, val: bool)
pub const fn set_e_pn0(&mut self, val: bool)
First PN (P-Transistor and N-Transistor processing) monitor control.
Sourcepub const fn e_pn1(&self) -> bool
pub const fn e_pn1(&self) -> bool
Second PN (P-Transistor and N-Transistor processing) monitor control.
Sourcepub const fn set_e_pn1(&mut self, val: bool)
pub const fn set_e_pn1(&mut self, val: bool)
Second PN (P-Transistor and N-Transistor processing) monitor control.
Sourcepub const fn divisor(&self) -> u8
pub const fn divisor(&self) -> u8
Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)
Sourcepub const fn set_divisor(&mut self, val: u8)
pub const fn set_divisor(&mut self, val: u8)
Ringo out Clock divider value. Frequency Output = Frequency input / (DIViSOR+1). (minimum = Frequency input / 16)
Sourcepub const fn div_update_req(&self) -> bool
pub const fn div_update_req(&self) -> bool
Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.
Sourcepub const fn set_div_update_req(&mut self, val: bool)
pub const fn set_div_update_req(&mut self, val: bool)
Ringo clock out Divider status flag. Set when a change is made to the divider value, cleared when the change is complete.